"""Setup."""
from setuptools import setup, find_packages

if __name__ == '__main__':
    setup(
        name='yyutils',
        version='0.0.1',
        packages=find_packages(),
        author='yyh',
        author_email='hyuyu1544@gmail.com',
        python_requires='>=3.6',
        url='https://github.com/hyuyu1544/yutils',
    )
